#!/usr/local/bin/perl -w

=head1 NAME

vcp.t - testing of vcp command

=cut

use strict ;

use Carp ;
use Test ;
use IPC::Run ;
use VCP::TestUtils ();

my %seen ;
my @perl = ( $^X, map {
      my $s = $_ ;
      $s = File::Spec->rel2abs( $_ ) ;
      "-I$s" ;
   } grep ! $seen{$_}++, @INC
) ;

## We always run vcp by doing a @perl, vcp, to make sure that vcp runs under
## the same version of perl that we are running under.
my $vcp = 'vcp' ;
$vcp = "bin/$vcp"    if -e "bin/$vcp" ;
$vcp = "../bin/$vcp" if -e "../bin/$vcp" ;

$vcp = File::Spec->rel2abs( $vcp ) ;

my @vcp = ( @perl, $vcp ) ;

# Note the spaces instead of tabs and the spaces after the null:
my $null_transfer = <<'END_TRANSFER';
Source:
        null:   

Destination:    null:  
END_TRANSFER

# Note the spaces instead of tabs and the spaces after the null:
my $identity_transfer = <<'END_TRANSFER';
Source:
        null:   

Destination:    null:  

Identity:
END_TRANSFER

sub vcp {
   my $exp_results = shift ;
   my $out ;
   my $err ;
   my $pid = IPC::Run::run [ @vcp, @_ ], \undef, \$out, \$err ;
   confess "$vcp ", join( ' ', @_ ), " returned $?\n$out$err"
      if defined $exp_results && ! grep $? == $_ << 8, @$exp_results ;
   return $err . $out ;
}


my @tests = (
#perldoc now complains when run as root, causing this test to fail
#sub { ok vcp( [ 0  ], 'help' ),            qr/OPTIONS/s                       },
sub {
   my $ok = eval {
       VCP::TestUtils::run [ @vcp, qw( null: null: ) ];
       1;
   };
   ok $ok || $@, 1, "vcp:-";
},
sub {
   my $ok = eval {
       VCP::TestUtils::run [ @vcp, qw( null: identity: null: ) ];
       1;
   };
   ok $ok || $@, 1, "vcp:-";
},
sub {
   my $ok = eval {
       VCP::TestUtils::run [ @vcp, qw( null: identity: identity: null: ) ];
       1;
   };
   ok $ok || $@, 1, "vcp:-";
},
sub {
   my $ok = eval {
       VCP::TestUtils::run [ @vcp, "vcp:-" ], "<", \$null_transfer;
       1;
   };
   ok $ok || $@, 1, "vcp:- < \$null_transfer";
},
sub {
   my $ok = eval {
       VCP::TestUtils::run [ @vcp, "vcp:-" ], "<", \$identity_transfer;
       1;
   };
   ok $ok || $@, 1, "vcp:- < \$identity_transfer";
},
sub { ok vcp( [ 2  ], 'foo:' ),             qr/unknown source scheme/s        },
sub { ok vcp( [ 2  ], 'revml:', 'foo:' ),   qr/unknown dest\w* scheme/s       },
sub { ok vcp( [ 1  ], '--foo' ),            qr/foo.*Usage/s                   },

) ;

plan tests => scalar( @tests ) ;

unless ( -e $vcp ) {
   print STDERR "# '$vcp' not found\n" ;
   skip( 1, '' ) for @tests ;
   exit ;
}

$_->() for @tests ;
